<?php 
require_once(dirname(__FILE__)."/../config.php");
CheckPurview('a_New,a_AccNew');
require_once(dirname(__FILE__)."/../../include/inc_photograph.php");
require_once(dirname(__FILE__)."/../../include/pub_oxwindow.php");
require_once(dirname(__FILE__)."/../inc/inc_archives_functions.php");

if(!isset($iscommend)) $iscommend = 0;
if(!isset($isjump)) $isjump = 0;
if(!isset($isbold)) $isbold = 0;
if(!isset($autokey)) $autokey = 0;
if(!isset($remote)) $remote = 0;
if(!isset($dellink)) $dellink = 0;
if(!isset($autolitpic)) $autolitpic = 0;

if($typeid==0){
	ShowMsg("请指定文档的栏目！","-1");
	exit();
}
if(empty($channelid)){
	ShowMsg("文档为非指定的类型，请检查你发布内容的表单是否合法！","-1");
	exit();
}
if(!CheckChannel($typeid,$channelid) || !CheckChannel($typeid2,$channelid)){
	ShowMsg("你所选择的栏目与当前模型不相符，请选择白色的选项！","-1");
	exit();
}
if(!TestPurview('a_New')) {
	CheckCatalog($typeid,"对不起，你没有操作栏目 {$typeid} 的权限！");
	if($typeid2!=0) CheckCatalog($typeid2,"对不起，你没有操作栏目 {$typeid2} 的权限！");
}

$arcrank = GetCoRank($arcrank,$typeid);

//对保存的内容进行处理
//--------------------------------
$iscommend = $iscommend + $isbold;

$pubdate = GetMkTime($pubdate);
$senddate = mytime();
$sortrank = AddDay($senddate,$sortup);
$cometime = GetMkTime($cometime);

if($ishtml==0) $ismake = -1;
else $ismake = 0;

$shorttitle = cn_substr($shorttitle,36);
$color =  cn_substr($color,10);
$writer =  '';
$source = '';
$description = cn_substr($description,250);
$keywords = cn_substr($keywords,60);
if(!TestPurview('a_Check,a_AccCheck,a_MyCheck')){ $arcrank = -1; }

//处理上传的图片
if(!isset($ddisremote)) $ddisremote = 1;
if(!isset($ddisremote2)) $ddisremote2 = 1;
$bigpic = UploadOneImage('bigpic',$bigpicname,$ddisremote2);
$litpic = GetDDImage('litpic',$picname,$ddisremote);
if($bigpic!='' && $litpic==''){
	$litpic = GetDDImage('ddfirst',$bigpic,0);
} 

$msg = stripslashes($msg);

//自动摘要
if($description=="" && $cfg_auot_description>0){
	$description = stripslashes(cn_substr(html2text($msg),$cfg_auot_description));
	$description = addslashes($description);
}
//把内容中远程的图片资源本地化
//------------------------------------
if($isUrlOpen && $remote==1){
	$msg = GetCurContent($msg);
}
//去除内容中的站外链接
//------------------------------------
if($dellink==1){
	$msg = str_replace($cfg_basehost,'#basehost#',$msg);
	$msg = preg_replace("/(<a[ \t\r\n]{1,}href=[\"']{0,}http:\/\/[^\/]([^>]*)>)|(<\/a>)/isU","",$msg);
  $msg = str_replace('#basehost#',$cfg_basehost,$msg);
}

$msg = addslashes($msg);
if($keywords!="") $keywords = trim(cn_substr($keywords,60))." ";

$adminID = $cuserLogin->getUserID();

//加入数据库的SQL语句
//----------------------------------
$inQuery = "INSERT INTO #@__archives(
typeid,typeid2,sortrank,iscommend,ismake,channel,
arcrank,click,money,title,shorttitle,color,writer,source,litpic,
pubdate,senddate,arcatt,adminID,memberID,description,keywords,templet,redirecturl,likeid) 
VALUES ('$typeid','$typeid2','$sortrank','$iscommend','$ismake','$channelid',
'$arcrank','0','$money','$title','$shorttitle','$color','$writer','$source','$litpic',
'$pubdate','$senddate','$arcatt','$adminID','0','$description','$keywords','$templet','$redirecturl','$likeid');";

$dsql = new DedeSql();
$dsql->SetQuery($inQuery);
if(!$dsql->ExecuteNoneQuery()){
	$dsql->Close();
	ShowMsg("把数据保存到数据库archives表时出错，请检查！","-1");
	exit();
}
$arcID = $dsql->GetLastID();


$assprice = ereg_replace("[^0-9\.-]","",$assprice);
if(empty($assprice)) $assprice = 0;

$inquery = "
  INSERT INTO #@__addonproduct(aid,typeid,assprice,bigpic,model,sptype,cometime,brand,size,stuff,msg)
  Values('$arcID','$typeid','$assprice','$bigpic','$model','$sptype','$cometime','$brand','$size','$stuff','$msg')
";

if(!$dsql->ExecuteNoneQuery($inquery)){
	$dsql->SetQuery("Delete From #@__archives where ID='$arcID'");
	$dsql->ExecuteNoneQuery();
	$dsql->Close();
	ShowMsg("把数据保存到数据库附加表addonarticle时出错，请检查原因！","-1");
	exit();
}
$dsql->Close();

//生成HTML
//---------------------------------

$artUrl = MakeArt($arcID,true);
if($artUrl=="") $artUrl = $cfg_plus_dir."/view.php?aid=$arcID";

//---------------------------------
//返回成功信息
//----------------------------------

$msg = "
　　请选择你的后续操作：
<a href='../product_add.php?cid=$typeid'><u>继续发布产品</u></a>
&nbsp;&nbsp;
<a href='$artUrl' target='_blank'><u>查看产品</u></a>
&nbsp;&nbsp;
<a href='../archives_do.php?aid=".$arcID."&dopost=editArchives'><u>更改产品</u></a>
&nbsp;&nbsp;
<a href='../catalog_do.php?cid=$typeid&dopost=listArchives'><u>已发布产品管理</u></a>
&nbsp;&nbsp;
<a href='../catalog_main.php'><u>网站栏目管理</u></a>
";

$wintitle = "成功发布产品！";
$wecome_info = "文章管理::发布产品";
$win = new OxWindow();
$win->AddTitle("成功发布产品：");
$win->AddMsgItem($msg);
$winform = $win->GetWindow("hand","&nbsp;",false);
$win->Display();
?>